@@ -32,7 +32,6 @@ sub alien_do_commands
     foreach my $dep ([ qw( Alien::Libxml2 Alien::LibXML ) ], qw( Alien::OpenSSL Alien::bz2 ))
     {
       my @dep = ref $dep ? @$dep : ($dep);
-      $DB::single = 1;
       foreach my $name (@dep)
       {
         my $alien = eval qq{ require $name; $name->new };
@@ -66,10 +65,21 @@ sub alien_do_commands
     }
     print "\n\n" unless $first;
   }
+  
+  
+  my $cc = ExtUtils::CChecker->new;
+  $cc->push_extra_compiler_flags('-fno-common');
+  if($cc->try_compile_run("int main(int argc, char *argv[]) { return 0; }"))
+  {
+    $cflags .= ' -fno-common';
+  }
 
   local $ENV{CFLAGS} = $cflags;
   local $ENV{LIBS}   = $libs;
   
+  print "CFLAGS=$cflags\n";
+  print "LIBS=$libs\n";
+  
   $self->SUPER::alien_do_commands($phase);
 }
 
